@@ -678,7 +678,7 @@ class Test(SquadObject):
 
     endpoint = '/api/tests/'
     attrs = ['url', 'id', 'name', 'short_name', 'status', 'result', 'test_run', 'log', 'has_known_issues',
-             'suite', 'known_issues', 'build', 'environment']
+             'suite', 'known_issues', 'build', 'environment', 'metadata']
 
     def __repr__(self):
         return self.short_name
